package jcg.demo.util;

import java.util.Random;
import java.util.Scanner;

/**
 * The constant data utility used in this Demo
 * 
 * @author Mary.Zheng
 *
 */
public final class DemoDataUtils {

	public static final int MESSAGE_SIZE = 10;
	public static final String DESTINATION = "test.queue";

	private static final String COMMA = ",";
	private static final String FAILOVER = "failover:(";

	private static final String HALF_MINUTE_TIMEOUT = ")?timeout=30000";

	private static String STANDALONE_BROKER_1 = "tcp://localhost:61616";
	private static String STANDALONE_BROKER_2 = "tcp://localhost:61716";

	private static String MASTER_BROKER_1 = "tcp://localhost:61816";
	private static String SLAVE_BROKER_2 = "tcp://localhost:61826";

	private static String[] STATIC_NC_BROKER = { "tcp://localhost:61516", MASTER_BROKER_1, SLAVE_BROKER_2 };
	private static String[] DYNAMIC_NC_BROKER = { "tcp://localhost:61626", "tcp://localhost:61636",
			"tcp://localhost:61646" };

	private static String getStaticNCBroker() {	 
		return STATIC_NC_BROKER[0];
	}
	
	private static String getDynamicNCBroker() {
		Random rand = new Random();
		int value = rand.nextInt(3);
		return DYNAMIC_NC_BROKER[value];
	}

	public static String buildDummyMessage(int value) {		 
		return "dummy message " + value;
	}

	private static String getFailOverURI(String... uris) {

		String[] brokerURIs = uris;
		StringBuffer foUrl = new StringBuffer(FAILOVER);

		int brokerUriSize = brokerURIs.length;
		if (brokerUriSize == 1) {
			foUrl.append(brokerURIs[0]);
		} else {
			for (String brokerUri : brokerURIs) {
				foUrl.append(brokerUri);
				if (!brokerUri.equalsIgnoreCase(brokerURIs[brokerUriSize - 1])) {
					foUrl.append(COMMA);
				}
			}
		}

		foUrl.append(HALF_MINUTE_TIMEOUT);// fast fails
		return foUrl.toString();
	}

	public static String readFailoverURL() {
		String promptyMessage = "Enter Demo Type for Failover:"
				+ "\n\t1 - Stand Alone Brokers \n\t2 - Master-Slave Brokers \n\t3 - Network of Brokers(Static) \n\t4 - Network of Brokers(Dynamic): ";
		System.out.println(promptyMessage);
		String failoverUrl = null;

		try (Scanner scanIn = new Scanner(System.in)) {
			String inputString = scanIn.nextLine();
			scanIn.close();
			switch (inputString) {
			case "1":
				failoverUrl = DemoDataUtils.getFailOverURI(STANDALONE_BROKER_1, STANDALONE_BROKER_2);
				break;
			case "2":
				failoverUrl = DemoDataUtils.getFailOverURI(MASTER_BROKER_1, SLAVE_BROKER_2);
				break;
			case "3":
				failoverUrl = DemoDataUtils.getFailOverURI(getStaticNCBroker());
				break;
			case "4":
				failoverUrl = DemoDataUtils.getFailOverURI(getDynamicNCBroker());
				break;
			}
		}

		return failoverUrl;
	}

}
